# -*- coding: utf-8 -*-
#
# Copyright (C) 2017 by Gregor Giesen
#
# This file is part of PEP487.
#
# PEP487 is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.
#
# PEP487 is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PEP487. If not, see <http://www.gnu.org/licenses/>.
#
"""pep487/version.py: version info"""

__author__ = "Gregor Giesen"
__copyright__ = "Copyright 2017, Gregor Giesen"
__credits__ = ["Martin Teichmann", "Gregor Giesen"]
__license__ = "GPLv3"
__version__ = "1.0.1"
__maintainer__ = "Gregor Giesen"
